 * --------------------------------------------------------------------
 * Do-file to replicate the key result of  
 *  Elsas, R. / Florysiak, D. (2013): Dynamic Capital Structure Adjustment and the Impact of Fractional Dependent Variables, 
 *     forthcoming Journal of Financial and Quantitative Analysis (JFQA). 
 * --------------------------------------------------------------------
* 
* Purpose: 
* 	Elsas and Florysiak (2013) analyze dynamic panel estimation with a fractional 
* 	(i.e. bounded) dependent variable in the context of empirically testing 
* 	capital structure theories with respect to the so-called speed of adjustment (SOA). 
* 	A new unbiased estimator is proposed and tested, called the DPF estimator.
* 	This do-file replicates the main result of Elsas/Floryisak (2013) bny setting up a Monte Carlo simulation that illsutrates unbiasedness of the DPF estimator 
* 	and the bias of alternatiove estimaors used in th literature (i.e. the fixed-effects, Blundell/Bond, LSDVC and long-difference estimators).  



* Please note:
* - This code requires to have xtdpf, xtld and xtlsdvc ado-files installed on Stata. xtdpf and xtld are available from our webpage, 
*   xtlsdvc can be installed from Stata repository
* - The simulation is based on the design described in Section III.A of Elsas/Florysiak 2013
* - The simulation compares the bias of the DPF estimator and benchmark estimators 
* 	and yields results similar to the results reported in Table 2.I, column 5, 
* 	and Figure 2 (censored) in Elsas/Florysiak (2013).  
* - For usability, the number of individuals and the number of replications are small in this code, with no quailtative effect on the bias results.
* - If one increases the number of individuals/time points, xtlsvc can become prohibitively slow.  
* - This code is designed to illustrate the key result of Elsas/Florysiak (2013) and has not been optimized for efficiency. 
*
* - Please report all bugs and problems to either elsas@bwl.lmu or florysiak@bwl.lmu.de
*	
* -----------------------------------------------------------------------
* Copyright: Ralf Elsas and David Florysiak, LMU Munich, 2013.
* -----------------------------------------------------------------------	
	
 clear

 * ---- Parameters for MC
 * number of reps
 local sim=100
 
 *number of periods and individuals
 local nindiv=100
 local ntime=10
 local nobs=1000
 
 * set-up matrices to store sim results
	matrix dpf=J(`sim',1,0)
    matrix fe=J(`sim',1,0)
    matrix blundellBond=J(`sim',1,0)
	matrix lsdvcEst=J(`sim',1,0)
	matrix ldEst=J(`sim',1,0)
	
	
    forvalues s=1(1)`sim' {
        quietly {
        clear
        set obs `nobs'

        * ---- Set parameters
        local rho=0.8
        gen i = mod(_n-1,`nindiv') + 1
        sort i
        gen t = mod(_n-1,`ntime') + 1
        gen z = -0.5 + 1.5 * runiform()
        gen a = rnormal(0,0.1)
        gen u = rnormal(0,0.1)

        * ---- Generate data according to DGP of DPF (Elsas/Floryiak Section III.A)
        by i: egen mean_zi = mean(z)
        by i: gen yHash = (1-`rho') * z * 1 + 0.1 - 0.25 * mean_zi + a[1] if t == 1
        gen y = .
        by i: replace y = 0 if yHash <= 0 & t == 1
        by i: replace y = yHash if yHash > 0 & yHash < 1 & t == 1
        by i: replace y = 1 if yHash >= 1 & t == 1
        by i: gen c = 0.1 + 0.1 * y[1] - 0.25 * mean_zi + a[1]
        forvalues k = 2(1)9 {
          by i: replace yHash = `rho' * y[_n-1] + (1-`rho') * z * 1 + c + u if t == `k'
          by i: replace y = 0 if yHash <= 0 & t == `k'
          by i: replace y = yHash if yHash > 0 & yHash < 1 & t == `k'
          by i: replace y = 1 if yHash >= 1 & t == `k'
        }

        * ---- Run xtdpf on generated dataset.
        xtset i t
        xtdpf y z
        matrix substitute dpf[`s',1]=_b[l1.y]

        * --- Compare to Alternative Estimnators (LD, LSDVC, Blundell/Bond and FE)
        xtdpdsys y z, twostep
        matrix substitute blundellBond[`s',1]=_b[L.y]
        
		xtreg y l1.y z, fe
        matrix substitute fe[`s',1]=_b[l1.y]
		
		xtlsdvc y z, initial(ab) bias(3)
		matrix substitute lsdvcEst[`s',1]=_b[l1.y]
		
		xtld y z, iter(3) difflength(6)
		matrix substitute ldEst[`s',1]=_b[LS6.y]
		
        }

    * ---- Analysis of Sim Results
    svmat dpf
    svmat fe
    svmat blundellBond
	svmat lsdvcEst
    svmat ldEst
	quietly {
        replace dpf1=1-dpf1
        replace fe1=1-fe1
        replace blundellBond1=1-blundellBond1
		replace lsdvcEst1=1-lsdvcEst1
		replace ldEst1=1-ldEst1
    }
    }
    summarize dpf* fe* blundellBond* lsdvcEst* ldEst*
    display as text "Note: Table shows average SOA estimates. The true value is 0.2"
